import { ElCheckbox, ElCheckboxGroup, ElOption, ElRadio, ElSelect } from 'element-plus'
import type { Component } from 'vue'

export interface CustomerOptions {
  title: string
  cover: string
  form_field: {
    field_name: string
    default_text: string
    is_required: 0 | 1
    field_type: 'input' | 'select' | 'checkbox' | 'radio' | 'textarea'
    props?: {
      type: string
    }
    synchronize_field?: {
      field_name: string
      synchrinize_to: string
      synchrinize_type: string
    }
    field_options?: {
      count: number
      option_name: string
      option_img_src: string
      tags: string[]
    }[]
    render: (
      filed: CustomerOptions['form_field'][number],
      defaultValue: Record<string, string | string[]>,
    ) => Component
  }[]
}

export const renderMap: Record<string, CustomerOptions['form_field'][number]['render']> = {
  select: (field, defaultValue) => {
    return (
      <ElSelect v-model={defaultValue[field.field_name]}>
        {field.field_options?.map((options) => {
          return <ElOption value={options.option_name} label={options.option_name} />
        })}
      </ElSelect>
    )
  },
  radio: (field, defaultValue) => {
    return (
      <ElRadio.RadioGroup v-model={defaultValue[field.field_name]}>
        {field.field_options?.map((options) => {
          return <ElRadio label={options.option_name}>{options.option_name}</ElRadio>
        })}
      </ElRadio.RadioGroup>
    )
  },
  checkbox: (field, defaultValue) => {
    return (
      <ElCheckboxGroup v-model={defaultValue[field.field_name]}>
        {field.field_options?.map((options) => {
          return <ElCheckbox value={options.option_name} label={options.option_name} />
        })}
      </ElCheckboxGroup>
    )
  },
}
