const BASE_URL = import.meta.env.VITE_BASE_URL + '/openwork'

interface Response<T> {
  code: number
  data: T
  message: string
}

export const request = async <T = Record<string, string>>({
  url,
  data,
  method = 'GET',
  ...options
}: RequestInit & { url: string; data?: Record<string, unknown> }): Promise<Response<T>> => {
  const formatDate = JSON.stringify(data)
  const r = await fetch(BASE_URL + url, {
    ...options,
    body: formatDate,
    method,
    mode: 'cors',
    cache: 'no-cache',
    headers: {
      'Content-Type': 'application/json',
      ...options.headers,
    },
  })
  const res = await r.json()
  return res
}
